@@ -2,12 +2,12 @@ package Net::IPAM::IP;
 
 use strict;
 use warnings;
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 use Socket qw/AF_INET AF_INET6/;
 
 # On some platforms, inet_pton accepts various forms of invalid input or discards valid input.
-# In this case use a (slower) pure perl implementation for Socket::inet_pton.
+# In this case use a (slower) pure-perl implementation for Socket::inet_pton.
 # and also for Socket::inet_ntop, I don't trust that too.
 BEGIN {
   if (    # wrong valid
@@ -34,6 +34,7 @@ our @EXPORT_OK = qw(incr_n);
 
 use overload
   '""'     => sub { shift->to_string },
+  bool     => sub { 1 },
   fallback => 1;
 
 =head1 NAME
@@ -66,7 +67,7 @@ Net::IPAM::IP - A library for reading, formatting, sorting and converting IP-add
 
 =head1 METHODS
 
-Net::IPAM::IP implements the following methods:
+L<Net::IPAM::IP> implements the following methods:
 
 =head2 new
 
@@ -115,7 +116,7 @@ sub new {
 
 =head2 clone
 
-Just a shallow copy
+Just a blessed shallow copy of the C<< {binary} >> attribute.
 
 =cut
 
@@ -169,7 +170,7 @@ sub new_from_bytes {
   $ip    = Net::IPAM::IP->new('10.0.0.1');
   $bytes = $ip->bytes;    # "\x0a\x00\x00\x01"
 
-Returns the packed IP address as byte-string. It's the opposite to new_from_bytes()
+Returns the packed IP address as byte-string. It's the opposite to L</"new_from_bytes">
 
 =cut
 
@@ -214,10 +215,9 @@ Returns 4 or 6.
 sub version {
   return $_[0]->{version} if defined $_[0]->{version};
 
-  # unpack first byte, AF_INETx
+  # unpack first byte, AF_INETx, 20% faster with substr()
   # my $v = unpack( 'C', $_[0]->{binary} );
-  #
-  # 20% faster with substr()
+
   my $v = ord( substr( $_[0]->{binary}, 0, 1 ) );
 
   # get, cache and return
@@ -236,7 +236,7 @@ Returns the input string in canonical form.
 
   say Net::IPAM::IP->new('Fe80::0001')->to_string;  # fe80::1
 
-Stringification is overloaded with C<to_string>
+Stringification is overloaded with L</"to_string">
 
   my $ip = Net::IPAM::IP->new('Fe80::0001') // die 'wrong format,';;
   say $ip; # fe80::1
@@ -250,13 +250,12 @@ Stringification is overloaded with C<to_string>
 #  return $_[0]->{string} = Socket::inet_ntop( $v, $n );
 #}
 
-# circumvent IPv4-compatible-IPv4 bug in Socket::inet_ntop
+# circumvent IPv4-compatible-IPv6 bug in Socket::inet_ntop
 sub to_string {
 
-  # unpack to version and network byte order (from Socket::inet_pton)
+  # unpack to version and network byte order (from Socket::inet_pton), 20% faster with substr()
   # my ( $v, $n ) = unpack( 'C a*', $_[0]->{binary} );
-  #
-  # 20% faster with substr()
+
   my ( $v, $n ) = ( ord( substr( $_[0]->{binary}, 0, 1 ) ), substr( $_[0]->{binary}, 1, ) );
 
   my $str = Socket::inet_ntop( $v, $n );
@@ -293,7 +292,7 @@ sub incr {
 
 =head2 expand
 
-Expand IP address into canonical form, useful for grep, aligned output and lexical sort.
+Expand IP address into canonical form, useful for C<< grep >>, aligned output and lexical C<< sort >>
 
 	Net::IPAM::IP->new('1.2.3.4')->expand;   # '001.002.003.004'
 	Net::IPAM::IP->new('fe80::1')->expand;   # 'fe80:0000:0000:0000:0000:0000:0000:0001'
@@ -303,9 +302,9 @@ Expand IP address into canonical form, useful for grep, aligned output and lexic
 sub expand {
   return $_[0]->{expand} if defined $_[0]->{expand};
 
-  # unpack to version and network byte order (from Socket::inet_pton)
+  # unpack to version and network byte order (from Socket::inet_pton), substr() ist faster than unpack
   # my ( $v, $n ) = unpack( 'C a*', $_[0]->{binary} );
-  # substr() ist faster
+
   my ( $v, $n ) = ( ord( substr( $_[0]->{binary}, 0, 1 ) ), substr( $_[0]->{binary}, 1, ) );
 
   if ( $v == AF_INET6 ) {
@@ -358,11 +357,11 @@ sub reverse {
 
 =head1 FUNCTIONS
 
-Net::IPAM::IP implements the following functions;
+L<Net::IPAM::IP> implements the following functions;
 
 =head2 incr_n($n)
 
-Increment packed IPv4 or IPv6 address, no need for Math::BigInt. Needed by methods in Net::IPAM::Block.
+Increment a packed IPv4 or IPv6 address, no need for L<Math::BigInt>. Needed by methods in L<Net::IPAM::Block>.
 
 =cut
 
@@ -520,9 +519,28 @@ sub _inet_pton_v6_pp {
   return $n;
 }
 
-=head1 WARNINGS
+=head1 OPERATORS
 
-Some Socket::inet_pton implementations are hopelessly buggy and are redefined during loading.
+L<Net::IPAM::IP> overloads the following operators.
+
+=head2 bool
+
+  my $bool = !!$ip;
+
+Always true.
+
+=head2 stringify
+
+  my $str = "$ip";
+
+Alias for L</"to_string">.
+
+=head1 WARNING
+
+Some Socket::inet_XtoY implementations are hopelessly buggy.
+
+Tests are made during loading and in case of errors, these functions are redefined
+with a (slower) pure-perl implementation.
 
 =head1 AUTHOR
 
